@@ -8,12 +8,11 @@ Created: 25/06/2021
 import typer
 from wasabi import msg
 
+from pytoil.config import defaults
+
 app = typer.Typer()
 
 
-PYTOIL_DOCS_URL: str = "https://followtheprocess.github.io/pytoil/"
-
-
 @app.command()
 def docs() -> None:  # pragma: no cover
     """
@@ -24,4 +23,4 @@ def docs() -> None:  # pragma: no cover
     $ pytoil docs
     """
     msg.info("Opening pytoil's docs in your browser...", spaced=True)
-    typer.launch(url=PYTOIL_DOCS_URL)
+    typer.launch(url=defaults.PYTOIL_DOCS_URL)
