@@ -8,11 +8,16 @@ Created: 18/06/2021
 
 import httpx
 import typer
+from rich import box
+from rich.console import Console
+from rich.table import Table
+from rich.text import Text
 from wasabi import msg
 
 from pytoil.api import API
 from pytoil.cli import utils
 from pytoil.config import Config
+from pytoil.repo import Repo
 
 app = typer.Typer(name="show")
 
@@ -244,3 +249,66 @@ def diff(
         else:
             for project in sorted(diff, key=str.casefold):
                 typer.echo(f"- {project}")
+
+
+@app.command()
+def forks(
+    count: bool = typer.Option(
+        False,
+        "--count",
+        "-c",
+        help="Display a count of the diff.",
+        show_default=False,
+    )
+) -> None:
+    """
+    Show your forked projects.
+
+    Show all the repos you own that are forks of other repos.
+
+    The "--count/-c" flag will show a count of forks.
+    """
+    config = Config.from_file()
+    utils.warn_if_no_api_creds(config)
+
+    api = API(username=config.username, token=config.token)
+
+    with msg.loading("Getting your Forks..."):
+        forks = api.get_fork_names()
+        parents = api.get_fork_parents(forks)
+
+        fork_parent_map = {fork: parent for fork, parent in zip(forks, parents)}
+
+    typer.secho("\nForked Projects:\n", fg=typer.colors.CYAN, bold=True)
+
+    if not forks:
+        msg.warn("You don't have any forks yet!", exits=0)
+
+    if count:
+        typer.echo(f"You have {len(fork_parent_map)} forked repos.")
+    else:
+        # Make a pretty table
+        table = Table(box=box.SIMPLE)
+        table.add_column("Project", justify="center")
+        table.add_column("Forked from", justify="center")
+        table.add_column("Location", justify="center")
+
+        # Populate the rows
+        for fork, parent in fork_parent_map.items():
+            fork_local = Repo(
+                owner=config.username,
+                name=fork,
+                local_path=config.projects_dir.joinpath(fork),
+            ).exists_local()
+
+            local_message = (
+                Text("Local", style="green")
+                if fork_local
+                else Text("Remote", style="yellow")
+            )
+
+            table.add_row(fork, parent, local_message)
+
+        # Show the table
+        console = Console()
+        console.print(table)
