@@ -2,12 +2,18 @@ from enum import Enum
 
 from pytoil.environments.abstract import Environment
 from pytoil.environments.conda import Conda
+from pytoil.environments.flit import FlitEnv
+from pytoil.environments.poetry import PoetryEnv
+from pytoil.environments.reqs import ReqTxtEnv
 from pytoil.environments.virtualenv import Venv
 
 __all__ = [
     "Environment",
     "Venv",
     "Conda",
+    "FlitEnv",
+    "PoetryEnv",
+    "ReqTxtEnv",
 ]
 
 
