@@ -13,11 +13,15 @@ import httpx
 import toml
 
 from pytoil.api import API
-from pytoil.environments import Conda, Environment, Venv
+from pytoil.environments import Conda, Environment, FlitEnv, PoetryEnv, ReqTxtEnv, Venv
 from pytoil.exceptions import RepoNotFoundError
 
 
 class Repo:
+    """
+    Wrapper around a user's local/remote repo.
+    """
+
     def __init__(self, owner: str, name: str, local_path: Path) -> None:
         """
         Representation of a local/remote project.
@@ -149,7 +153,6 @@ class Repo:
         Returns:
             bool: True if setuptools, else False.
         """
-
         return self.file_exists("setup.cfg") or self.file_exists("setup.py")
 
     def has_pyproject_toml(self) -> bool:
@@ -159,7 +162,6 @@ class Repo:
         Returns:
             bool: True if yes, else False.
         """
-
         return self.file_exists("pyproject.toml")
 
     def is_conda(self) -> bool:
@@ -173,7 +175,7 @@ class Repo:
         """
         return self.file_exists("environment.yml")
 
-    def _specifies_build_tool(self, build_tool: str) -> bool:
+    def specifies_build_tool(self, build_tool: str) -> bool:
         """
         Generalised method to check for a particular
         build tool specification in pyproject.toml.
@@ -219,8 +221,7 @@ class Repo:
         Returns:
             bool: True if yes, else False
         """
-
-        return self._specifies_build_tool("poetry")
+        return self.specifies_build_tool("poetry")
 
     def is_flit(self) -> bool:
         """
@@ -229,8 +230,7 @@ class Repo:
         Returns:
             bool: True if yes, else False
         """
-
-        return self._specifies_build_tool("flit")
+        return self.specifies_build_tool("flit")
 
     def dispatch_env(self) -> Optional[Environment]:
         """
@@ -244,10 +244,31 @@ class Repo:
             Optional[BaseEnvironment]: Either the correct environment
                 object if it was able to detect. Or None.
         """
+        # This is where the magic happens for automatic environment detection
+        # and installation
+
+        # Each of the environment objects below has an `install_self` method
+        # which does the correct thing for each type of environment
 
         if self.is_conda():
+            # Conda projects might also contain some of the below files
+            # check for environment.yml first so this works as expected
             return Conda(name=self.name, project_path=self.local_path)
+
+        elif self.file_exists("requirements.txt") or self.file_exists(
+            "requirements_dev.txt"
+        ):
+            return ReqTxtEnv(project_path=self.local_path)
+
         elif self.is_setuptools():
             return Venv(project_path=self.local_path)
+
+        elif self.is_poetry():
+            return PoetryEnv(project_path=self.local_path)
+
+        elif self.is_flit():
+            return FlitEnv(project_path=self.local_path)
         else:
+            # We couldn't detect an appropriate environment
+            # this is handled by the CLI
             return None
